# zfs_uploader
Work in progress. Use at your own risk!

## Release Instructions
1. Increment version in `__init__.py` file
2. Update `CHANGELOG.md` with new version
3. Tag release in GitHub when ready. Add changelog items to release 
   description. GitHub Action workflow will automatically build and push 
   the release to PyPi.
